# Prolific PL2303 USB to Serial Driver
# 2016-2017 foo.li systeme + software

$packageName    = 'prolific-pl2303-driver'
$version        = '1.18.0'
$intver         = '1180'
$fileType       = 'exe'
#$silentArgs     = '/s' #even if they write it in the release notes - it just doesn't work...
$packageSearch  = 'PL2303 USB-to-Serial Driver'
$checksum       = '4B2AD199C095F9C76FD5147F6BADA4481F1AE335'
$checksumType   = 'sha1'
$localfile      = '\\unxfsv001\software\drivers\o\openvpn\securepoint\PL2303_Prolific_DriverInstaller_v_' + $intver + '.exe'
$unpackDir      = New-Item "${ENV:TEMP}\prolific" -ItemType Directory -Force
$unpackFile     = "${ENV:TEMP}\prolific.zip"
$setupFile      = Join-Path "$unpackDir" "PL2303_Prolific_DriverInstaller_v1180.exe"


try {
    $app = Get-ItemProperty -Path @('HKLM:\Software\Wow6432Node\Microsoft\Windows\CurrentVersion\Uninstall\*',
                                    'HKLM:\Software\Microsoft\Windows\CurrentVersion\Uninstall\*') `
            -ErrorAction:SilentlyContinue | Where-Object { $_.DisplayName -like $packageSearch }

    if ($app -and ([version]$app.DisplayVersion -ge '1.5')) {
        Write-Output $(
        'Siemens LOGO ' + $mainversion + ' is already installed. ' +
        'No need to download and install again. Otherwise uninstall first.'
        )
    } else {
        Write-Host "going to download installer from prolific website..."
        $url    =  'http://prolificusa.com/files/PL2303_Prolific_DriverInstaller_v' + $intver + '.zip'
        #$url64  = $url
        Write-Host "Downloading Release" $version "from Prolific..."
        Get-ChocolateyWebFile $packageName $unpackFile $url $url64 `
            -checksum $checksum -checksumType $checksumType #`
            #-checksum64 $checksum -checksumType64 $checksumType
        #unzip downloaded zip
        Get-ChocolateyUnzip $unpackFile $unpackDir
        Install-ChocolateyInstallPackage $packageName $fileType $silentArgs $setupFile
        #delete downloaded file
        Remove-Item -Path $unpackDir -Recurse -Force -ErrorAction SilentlyContinue
        Remove-Item -Path $unpackFile -Force -ErrorAction SilentlyContinue
    }
} catch {
    throw $_.Exception
}